@@ -13,7 +13,9 @@ LOGGER = logging.getLogger(__name__)
 
 class TemplateVariableSubstitutionTransformer(Transformer):
     """
-    Transforms dictionary into model
+    Add/Replace field in Dict by string.format based on given template and provide record Dict as a template parameter
+    https://docs.python.org/3.4/library/string.html#string.Formatter.format
+
     """
 
     def init(self, conf):
